@@ -1,16 +1,10 @@
 
 package Date::Formatter;
-{
-  $Date::Formatter::VERSION = '0.10.1';
-}
 
 use strict;
 use warnings;
 
-use Scalar::Util qw(blessed);
-
-use Time::Local ();
-use DateTime::Locale;
+our $VERSION = '0.01';
 
 ## overload operators
 use overload (
@@ -22,80 +16,38 @@ use overload (
 	'-'   => "subtract"
 	);
 
+## class constants
+# date name constants
+use constant DAYS => [ qw(Sunday Monday Tuesday Wednesday Thursday Friday Saturday) ];
+use constant MONTHS => [ qw(January February March April May June July August September October November December) ]; 
+
 ### constructor
 
 sub new {
-	my ($_class, %date) = @_;
+	my ($_class) = @_;
 	my $class = ref($_class) || $_class;
 	my $date = {};
 	bless($date, $class);
-	$date->_init(%date);
+	$date->_init();
 	return $date;
 }
 
-
-sub now {
-    my ( $self, %date ) = @_;
-    my $locale = $date{locale} || 'en';
-    return $self->new( locale => $locale );
-}
+# alias "now" for "new" as an 
+# alternate constructor semantic
+*now = \&new;
 
 sub _init {
-	my ($self, %date) = @_;
+	my ($self) = @_;
 	$self->{hourType} = 12;
 	$self->{abbreviateMonths} = 0;
 	$self->{abbreviateDays} = 0;
 	$self->{formatter} = undef;
-	$self->{internal} = undef;
-	$self->{elements} = [];
+	$self->{internal} = [];
+	$self->{elements} = undef;
 	$self->{am_or_pm} = undef;
 	$self->{gmt_offset_hours} = undef;
 	$self->{gmt_offset_minutes}	= undef;
-
-    $self->setLocale( delete $date{locale} );
-
-    if (%date) {      
-        # we let Time::Local do the range checking
-        # on these values here,.. 
-        $date{seconds}      = 0 unless exists $date{seconds};
-        $date{minutes}      = 0 unless exists $date{minutes};
-        $date{hour}         = 0 unless exists $date{hour};
-        $date{year}         = 0 unless exists $date{year};
-        $date{day_of_month} = 1 unless exists $date{day_of_month};
-        # we accept normal month values
-        # instead of zero index months
-        if (exists $date{month}) {
-            ($date{month} =~ /^\d+$/ && $date{month} >= 1) 
-                || die "Insufficient Arguments : 'month' value must be numeric and at least 1";        
-            $date{month} -= 1; 
-        }
-        else {
-        	$date{month} = 0; 
-        }        
-        my $new_time;
-        eval {
-            $new_time = Time::Local::timelocal(
-                            $date{seconds}, $date{minutes}, $date{hour},
-                            $date{day_of_month}, $date{month}, $date{year}
-                        );
-        };
-        die "Insufficient Arguments : Could not construct a proper date value : $@" if $@;
-        $self->_setTime($new_time);    
-    }
-    else {
-        $self->_setTime(time());
-    }
-}
-
-sub setLocale {
-    my $self = shift;
-    my ($locale) = @_;
-
-    $locale ||= 'en';
-
-    $self->{locale} = DateTime::Locale->load( $locale );
-
-    return;
+	$self->_setTime(time());
 }
 
 ## alternate constructor 
@@ -217,8 +169,7 @@ sub getDateFormatter {
 
 sub setDateFormatter {
 	my ($self, $formatter) = @_;
-	(defined($formatter) && ref($formatter) eq "CODE") 
-        || die "Insufficient Arguments : bad formatter";
+	(defined($formatter) && ref($formatter) eq "CODE") || die "Insufficient Arguments : bad formatter";
 	$self->{formatter} = $formatter;
 }
 
@@ -366,9 +317,9 @@ sub getDayOfMonth {
 sub getMonth {
 	my ($self) = @_;
 	if ($self->{abbreviateMonths} == 1){
-        return $self->{locale}->month_format_abbreviated->[$self->{elements}[4]];
+		return (MONTHS->[$self->{elements}->[4]] =~ /(...)/);	
 	}
-    return $self->{locale}->month_format_wide->[$self->{elements}[4]];
+	return MONTHS->[$self->{elements}->[4]];
 }
 
 sub getNumericMonth {
@@ -393,21 +344,10 @@ sub getYear {
 
 sub getDayOfWeek {
 	my ($self) = @_;
-
-    my @days;
 	if ($self->{abbreviateDays} == 1){
-        @days = @{$self->{locale}->day_format_abbreviated};
+		return (DAYS->[$self->{elements}->[6]] =~ /(...)/);	
 	}
-    else {
-        @days = @{$self->{locale}->day_format_wide};
-    }
-
-    # DateTime::Locale has Monday as the first day. This module
-    # uses Sunday. So, move the last item to the front, so @days
-    # is now Sunday -> Saturday instead of Monday -> Sunday.
-    unshift(@days, pop(@days));
-
-	return $days[$self->{elements}->[6]];
+	return DAYS->[$self->{elements}->[6]];
 }
 
 sub getDayOfWeekIndex {
@@ -437,12 +377,7 @@ sub pack {
 sub unpack {
 	# this is an alternate constructor 
 	my ($class, $packed_string) = @_;
-	my $obj = _setTime($class->new(), $packed_string);
-
-    #Uncomment if you want clones to clone the locale, as well
-    #$obj->{locale} = $self->{locale};
-
-    return $obj;
+	return _setTime($class->new(), $packed_string);
 }
 
 ## printing
@@ -471,7 +406,7 @@ sub stringValue {
 
 sub add {
 	my ($left, $right) = @_;
-	(blessed($right) && $right->isa("Date::Formatter")) 
+	(UNIVERSAL::isa($left, "Date::Formatter") && UNIVERSAL::isa($right, "Date::Formatter")) 
 		|| die "Illegal Operation : Cannot add a date object to a non-date object.";
 	return _setTime($left->clone(), $left->{internal} + $right->{internal});
 }
@@ -484,7 +419,7 @@ sub add {
 
 sub subtract {
 	my ($left, $right) = @_;
-	(blessed($right) && $right->isa("Date::Formatter"))   
+	(UNIVERSAL::isa($left, "Date::Formatter") && UNIVERSAL::isa($right, "Date::Formatter"))  
 		|| die "Illegal Operation : Cannot subtract a date object from a non-date object.";
 	return _setTime($left->clone(), $left->{internal} - $right->{internal});
 }
@@ -498,7 +433,7 @@ sub subtract {
 # compare two dates
 sub compare {
 	my ($left, $right) = @_;
-	(blessed($right) && $right->isa("Date::Formatter"))  
+	(UNIVERSAL::isa($left, "Date::Formatter") && UNIVERSAL::isa($right, "Date::Formatter")) 
 		|| die "Illegal Operation : Cannot compare a date object to a non-date object.";
 	return ($left->{internal} <=> $right->{internal});
 }
@@ -514,13 +449,17 @@ sub notEqual {
 }
 
 
+1;
+
+__DATA__
+
 1;
 
 __END__
 
 =head1 NAME
 
-Date::Formatter - A simple Date and Time formatting object 
+Date-Formatter - A simple Date and Time formatting object 
 
 =head1 SYNOPSIS
 
@@ -562,15 +501,9 @@ This module provides a fast and very flexible mini-language to be used in format
 
 =over 4
 
-=item B<new (%date)>
+=item B<new>, B<now> 
 
-The C<new> constructor will return an new instance representing the current time. It also accepts an optional C<%date> descriptor. The C<%date> can contain the following fields: I<hour, minutes, seconds, day_of_month, month, and year>. The values in C<%date> are then used to construct a new object with that date. 
-
-B<NOTE:> You can leave out values in C<%date>, most of the time they will default to 0. For detailed information on how the C<%date> values are handled I suggest consulting the L<Time::Local> documentation. It should be noted though that we handle I<month> values as 1 .. 12 and not the 0 .. 11 that L<Time::Local> does.
-
-=item B<now> 
-
-The C<now> constructor will create a B<Date::Formatter> object with the current time.
+C<new> or C<now> will create a B<Date::Formatter> object with the current time.
 
 =item B<createTimeInterval (%date_info)>
 
@@ -587,6 +520,10 @@ Accepts the following named arguments:
  minutes
  seconds
 
+B<NOTE:> 
+
+This can also be used to set a time sometime past the epoch, but that is not terribly useful. Except maybe to pass in nothing and get the date of the epoch on your current system.
+
 =item B<refresh>
 
 Occasionally you will want to refresh the time to be the current time. This would allow a B<Date::Formatter> object to be used over a long period of time.
@@ -595,10 +532,14 @@ Occasionally you will want to refresh the time to be the current time. This woul
 
 =head2 Formatted Output Methods
 
-The formatted output methods are means of customizing the string output of the B<Date::Formatter> object. The C<createDateFormatter> is at the heart of this group, it implements a mini-language for formatting dates. The internal parser in C<createDateFormatter> has been optimized to make this a very usable operation, as it will be one of the most common uses of this object.
-
 =over 4
 
+The formatted output methods are means of customizing the string output of the B<Date::Formatter> object. The C<createDateFormatter> is at the heart of this group, it implements a mini-language for formatting dates. 
+
+B<NOTE:> 
+
+That the internal parser in C<createDateFormatter> has been optimized to make this a very usable operation, as it will be one of the most common uses of this object.
+
 =item B<createDateFormatter ($format_string)>
 
 All date tokens must be enclosed in parantheses (or some other seperator for which you must provide the regular expression that C<split> will use to tokenize the string). The formatter will use the current settings for 12 or 24 hour clock as well as the abbreviated day and month names. Here is a description of the available tokens and what they output:
@@ -655,16 +596,10 @@ here is a format that will exactly mimic the default date format
 
 =item B<getDateFormatter>
 
-Returns the formatter subroutine, so you can share between multiple B<Date::Formatter> objects if you like.
+returns the formatter subroutine, so you can share between multiple B<Date::Formatter> objects if you like.
 
 =item B<setDateFormatter ($func)>
 
-Sets the formatter routine, this is how one would share that formatter routine mentioned above.
-
-=item B<setLocale ($locale)>
-
-Sets (or resets) the locale. The default is 'en'.
-
 =back
 
 =head2 Configuration methods
@@ -753,7 +688,7 @@ These methods overload the + and - operators respectively.
 
 =item B<toString>
 
-This method returns the formatted string as specified by the C<createDateFormatter> method. This is used to overload the '""' stringification operator.
+A C<toString> method is implemented, and used to overload the '""' stringification operator.
 
 =item B<compare>
 
@@ -800,9 +735,9 @@ The Date::Formatter class is epoch limited. Below is a note about this from perl
 
 =head1 TO DO 
 
-Using date formatters on time intervals does not always make sense, as it will just give you a representation of the interval past after the epoch. Possibly consider an alternate format for intervals. This would likely require some reworking of the way intervals are handled so it is only an idea for now.
+Possibly incorporate a timer class with this as well, with C<start> and C<stop> methods.
 
-This documentation needs some work.
+Using date formatters on time intervals does not always make sense, as it will just give you a representation of the interval past after the epoch. Possibly consider an alternate format for intervals. This would likely require some reworking of the way intervals are handled so it is only an idea for now.
 
 =head1 BUGS
 
@@ -812,20 +747,23 @@ None that I am aware of. The code is pretty thoroughly tested (see L<CODE COVERA
 
 I use B<Devel::Cover> to test the code coverage of my tests, below is the B<Devel::Cover> report on this module's test suite.
 
- ------------------------ ------ ------ ------ ------ ------ ------ ------
- File                       stmt branch   cond    sub    pod   time  total
- ------------------------ ------ ------ ------ ------ ------ ------ ------
- Date/Formatter.pm         100.0   95.8   74.5  100.0  100.0  100.0   96.4
- ------------------------ ------ ------ ------ ------ ------ ------ ------
- Total                     100.0   95.8   74.5  100.0  100.0  100.0   96.4
- ------------------------ ------ ------ ------ ------ ------ ------ ------
+ ---------------------------------------- ------ ------ ------ ------ ------ ------ ------
+ File                                       stmt branch   cond    sub    pod   time  total
+ ---------------------------------------- ------ ------ ------ ------ ------ ------ ------
+ /Date/Formatter.pm                        100.0   96.2   62.2  100.0  100.0  100.0   94.5
+ t/10_Date_Formatter_test.t                100.0   50.0   33.3    n/a    n/a   85.3   92.0
+ t/20_Date_Formatter_overloads_test.t      100.0    n/a    n/a  100.0    n/a    3.7  100.0
+ t/30_Date_Formatter_formatter_test.t      100.0    n/a    n/a  100.0    n/a   19.7  100.0
+ t/40_Date_Formatter_serialization_test.t  100.0    n/a    n/a    n/a    n/a    0.6  100.0
+ t/50_Date_Formatter_interval_test.t       100.0    n/a    n/a    n/a    n/a    1.1  100.0
+ ---------------------------------------- ------ ------ ------ ------ ------ ------ ------
+ Total                                     100.0   92.9   60.4  100.0  100.0  100.0   95.5
+ ---------------------------------------- ------ ------ ------ ------ ------ ------ ------
 
 =head1 SEE ALSO
 
 The accessor interface to this module was inspired by and at times directly ripped off from the Javascript and Java Date objects.
 
-This module uses L<Time::Local> when creating dates with the C<%date> parameter to C<new()>.
-
 For serious date/time involved work, skip my module and go straight to the
 DateTime project at L<http://datetime.perl.org>. Don't even waste your time 
 with anything else.
@@ -837,39 +775,37 @@ Below is a list of other Date/Time modules I have looked over in the past, and m
 
 =over 5
 
-=item L<Class::Date>
+=item B<Class::Date>
 
 This module seems pretty nice, I have never used it. It is much more ambitious than my module, but in my opinion provides inferior formatting capabilties.
 
-=item L<Date::Simple>
+=item B<Date::Simple>
 
 If you have to manipulate just dates (it doesnt handle time), then this is a pretty good module. It provides an XS as well as a Pure Perl version. 	
 
-=item L<Time::Format>
+=item B<Time::Format>
 
 This module is available as both an XS or a Pure perl version. It provides a funky global hash which can be used to easily format a UNIX time value. It does seem quite extensive, and is a nice way of going about this. But it is not OO at all, which is much of where it differs from my module.
 
-=item L<Date::Format>
+=item B<Date::Format>
 
 A pretty nice formatting module, but purely functional in style. Not that thatis bad, just that its not the same as our OO version.	
 
-=item L<Time::Object>
+=item B<Time::Object>
 
-=item L<Time::localtime>
+=item B<Time::localtime>
 
 Are both wrappers/helpers/extensions around the C<localtime> and C<gmttime> functions.
 
 =back
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Stevan Little, E<lt>stevan@iinteractive.comE<gt>
-
-Rob Kinyon, E<lt>rob@iinteractive.comE<gt>
+stevan little, E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2007 Infinity Interactive, Inc.
+Copyright 2004 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
